

# Pygame GUI
A GUI system for pygame 2 (it also works OK on pygame 1.9).

 - [Documentation](https://pygame-gui.readthedocs.io/en/latest/index.html)
 - [GitHub](https://github.com/MyreMylar/pygame_gui)
 - [Examples](https://github.com/MyreMylar/pygame_gui_examples)
 - [PyPi](https://pypi.org/project/pygame-gui/)

[![pypi](https://badge.fury.io/py/pygame-gui.svg)](https://pypi.python.org/pypi/pygame-gui) [![Documentation Status](https://readthedocs.org/projects/pygame-gui/badge/?version=latest)](https://pygame-gui.readthedocs.io/en/latest/?badge=latest) [![Python 3.5+](https://img.shields.io/badge/python-3.5+-blue.svg)](https://www.python.org/downloads/release/python-350/) [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT) [![Master](https://travis-ci.com/MyreMylar/pygame_gui.svg?branch=master)](https://travis-ci.com/MyreMylar/pygame_gui) [![codecov](https://codecov.io/gh/MyreMylar/pygame_gui/branch/master/graph/badge.svg)](https://codecov.io/gh/MyreMylar/pygame_gui)

## Requirements

 - Python 3.5+
 - Pygame

## How to install

1. Run this command in a command prompt:
```
pip install pygame_gui
```
2. If all goes well you should see a message about game_gui being installed successfully and will be able to find pygame_gui in the list of installed packages for your python interpreter (PyCharm displays these as a nice list under File->Settings->Project:project_name->Project Interpreter). 
3. Should you need to delete pygame_gui for any reason then PyCharm will also let you do that from the same Project Interpreter settings window using the red minus symbol button.

## How to upgrade to the latest version

Run this command in a command prompt:

```
pip install pygame_gui -U
```

Or, you may be able to use your IDE to update the library (PyCharm lets you update modules in it's interpreter settings).

## Making use of the library

There is documentation available [here](https://pygame-gui.readthedocs.io/en/latest/index.html), you can also try out the examples at the [pygame_gui_examples repository](https://github.com/MyreMylar/pygame_gui_examples).

## Screenshots of Pygame GUI

![pygame_gui_example_1](https://user-images.githubusercontent.com/13382426/69264498-57ec8980-0bbf-11ea-9883-cac9c854615d.png)

![example_2](https://user-images.githubusercontent.com/13382426/69264921-2f18c400-0bc0-11ea-8a11-d9abd4e969b4.png)

![pygame_gui_example_3](https://user-images.githubusercontent.com/13382426/68039142-5ec06480-fcc3-11e9-91f4-3e401f459886.png)

![pygame_gui_example_4](https://user-images.githubusercontent.com/13382426/68041632-e52b7500-fcc8-11e9-8b72-4cf8817c5fa3.png)
